@@ -114,7 +114,9 @@ class MinkowskiChannelwiseConvolution(MinkowskiModuleBase):
         """
 
         super(MinkowskiChannelwiseConvolution, self).__init__()
-        assert dimension > 0, f"dimension must be a positive integer, {dimension}"
+        assert (
+            dimension > 0
+        ), f"Invalid dimension. Please provide a valid dimension argument. dimension={dimension}"
 
         if kernel_generator is None:
             kernel_generator = KernelGenerator(
@@ -169,7 +171,7 @@ class MinkowskiChannelwiseConvolution(MinkowskiModuleBase):
         N_out = cm.size(out_key)
         out_F = input._F.new(N_out, self.in_channels).zero_()
 
-        kernel_map = cm.get_kernel_map(
+        kernel_map = cm.kernel_map(
             in_key,
             out_key,
             self.kernel_generator.kernel_stride,
