@@ -32,7 +32,6 @@
 #include <vector>
 
 #ifndef CPU_ONLY
-#include <thrust/device_vector.h>
 #include <thrust/host_vector.h>
 #endif
 
@@ -71,11 +70,6 @@ template <typename T>
 std::ostream &operator<<(std::ostream &out, const thrust::host_vector<T> &v) {
   return print_vector(out, v);
 }
-
-template <typename T>
-std::ostream &operator<<(std::ostream &out, const thrust::device_vector<T> &v) {
-  return print_vector(out, v);
-}
 #endif
 
 template <typename T>
